<?php

/**
 * A comment.
 *
 * @author {@link mailto:corey@onpubco.com Corey HM Taylor}
 * @copyright Onpub (TM) Copyright (C) 2007, Onpubco
 * {@link http://onpubco.com/}
 * @license http://www.gnu.org/copyleft/gpl.html GNU General Public License
 * Version 2
 * @package OnpubAPI
 * @version 0.8.6
 */
class OnpubComment
{
    /**
     * Comment ID. Default is null.
     *
     * @var int
     */
    public $ID;
    /**
     * Image ID. Default is null.
     *
     * @var int
     */
    public $imageID;
    /**
     * Article ID. Default is null.
     *
     * @var int
     */
    public $articleID;
    /**
     * Author ID. Default is null.
     *
     * @var int
     */
    public $authorID;
    /**
     * Parent comment ID. Default is null.
     *
     * @var int
     */
    public $parentID;
    /**
     * Comment title. Default is an empty string.
     *
     * @var string
     */
    public $title;
    /**
     * Comment content. Default is an empty string.
     *
     * @var string
     */
    public $content;
    /**
     * Comment URL. Default is an empty string.
     *
     * @var string
     */
    public $url;
    private $created;
    private $modified;
    /**
     * Comment author. Default is null.
     *
     * @var OnpubAuthor
     */
    public $author;
    /**
     * Comment image. Default is null.
     *
     * @var OnpubImage
     */
    public $image;

    /**
     * Construct a new comment.
     */
    function __construct()
    {
        $this->ID = null;
        $this->imageID = null;
        $this->articleID = null;
        $this->authorID = null;
        $this->parentID = null;
        $this->title = "";
        $this->content = "";
        $this->url = "";
        $this->created = null;
        $this->modified = null;
        $this->author = null;
        $this->image = null;
    }

    /**
     * Get this comment's creation date.
     *
     * By default, returns the date at the time this method was called for the
     * first time. Call {@link OnpubComment::setCreated()} to explicitly set
     * this comment's creation date.
     *
     * @return DateTime
     */
    public function getCreated()
    {
        if ( $this->created === null ) {
            $this->created = new DateTime();
        }

        return $this->created;
    }

    /**
     * Set this comment's creation date.
     *
     * @param DateTime
     */
    public function setCreated( DateTime $created )
    {
        $this->created = $created;
    }

    /**
     * Get this comment's last modification date.
     *
     * By default, returns the date at the time this method was called for the
     * first time. Call {@link OnpubComment::setModified()} to explicitly set
     * this comment's last modification date.
     *
     * @return DateTime
     */
    public function getModified()
    {
        if ( $this->modified === null ) {
            $this->modified = new DateTime();
        }

        return $this->modified;
    }

    /**
     * Set this comment's last modification date.
     *
     * @param DateTime
     */
    public function setModified( DateTime $modified )
    {
        $this->modified = $modified;
    }

    /**
     * Get a summary of this comment's content.
     *
     * By default a 30 word summary is generated.
     *
     * @param int $limit The maximum number of words to include in the summary.
     * @return string
     */
    public function getSummary( $limit = 30 )
    {
        $words = preg_split( "/\s+/", trim( strip_tags( $this->content ) ), $limit + 1 );
        array_pop( $words );
        return implode( ' ', $words );
    }
}

?>
