<?php

/**
 * Manage an Onpub database.
 *
 * @author {@link mailto:corey@onpubco.com Corey HM Taylor}
 * @copyright Onpub (TM) Copyright (C) 2007, Onpubco
 * {@link http://onpubco.com/}
 * @license http://www.gnu.org/copyleft/gpl.html GNU General Public License
 * Version 2
 * @package OnpubAPI
 * @version 0.8.6
 */
class OnpubDatabase
{
    const MYSQL_TABLES_CREATE_FILE = 'api/sql/create_onpub_mysql_tables.sql';
    const MYSQL_TABLES_DELETE_FILE = 'api/sql/delete_onpub_mysql_tables.sql';
    const SQLITE_TABLES_CREATE_FILE = 'api/sql/create_onpub_sqlite_tables.sql';
    const SQLITE_TABLES_DELETE_FILE = 'api/sql/delete_onpub_sqlite_tables.sql';
    private $pdo;

    /**
     * Connect to a database.
     *
     * All the methods in this class which query the database use the database
     * connection provided by the PDO object required by this constructor.
     * Currently, Onpub only supports MySQL as a database for storing content.
     * Therefore, when constructing the PDO object, only the
     * {@link PHP_MANUAL#ref.pdo-mysql PDO_MYSQL} driver is supported
     * as a PDO {@link PHP_MANUAL#ref.pdo-mysql.connection data source}.
     *
     * @param PDO $pdo A {@link PHP_MANUAL#function.pdo-construct PHP Data Object}.
     */
    function __construct( PDO $pdo )
    {
        $this->pdo = $pdo;
        $this->pdo->setAttribute( PDO::ATTR_EMULATE_PREPARES, true );
    }

    /**
     * Backup the database.
     *
     * This method is not yet fully implemented!
     */
    public function backup()
    {
        $oaamaps = new OnpubAAMaps( $this->pdo );
        $oarticles = new OnpubArticles( $this->pdo );
        $oauthors = new OnpubAuthors( $this->pdo );
        $oimages = new OnpubImages( $this->pdo );
        $osamaps = new OnpubSAMaps( $this->pdo );
        $osections = new OnpubSections( $this->pdo );
        $owebsites = new OnpubWebsites( $this->pdo );
        $owsmaps = new OnpubWSMaps( $this->pdo );

        $queryOptions = new OnpubQueryOptions();
        $rowLimit = 100;
        $queryOptions->setPage( 1, $rowLimit );

        $now = new DateTime();
        $time = str_replace( ' ', '-', $now->format( 'M j, Y g:i:s A' ) );
        $time = str_replace( ',', '', $time );
        $time = str_replace( ':', '-', $time );
        $servername = str_replace( '.', '-', $_SERVER['SERVER_NAME'] );
        $prefix = "onpub-tables_" . $servername . "_" . $time;
        $suffix = ".sq3";
        $tempname = tempnam( '/tmp' , $prefix ) . $suffix;

        if ( touch( $tempname ) ) {
            try {
                $sqlite = new PDO( "sqlite:" . $tempname, '', '' );
            }
            catch ( PDOException $e ) {
                throw $e;
            }

            $odatabase = new OnpubDatabase( $sqlite );

            try {
                $odatabase->install();
            }
            catch ( PDOException $e ) {
                throw $e;
            }

            $liteaamaps = new OnpubAAMaps( $sqlite );
            $litearticles = new OnpubArticles( $sqlite );
            $liteauthors = new OnpubAuthors( $sqlite );
            $liteimages = new OnpubImages( $sqlite );
            $litesamaps = new OnpubSAMaps( $sqlite );
            $litesections = new OnpubSections( $sqlite );
            $litewebsites = new OnpubWebsites( $sqlite );
            $litewsmaps = new OnpubWSMaps( $sqlite );

            while ( sizeof( ($aamaps = $oaamaps->select( $queryOptions )) ) ) {
                $result = $liteaamaps->insert( $aamaps );
                $page++;
                $queryOptions->setPage( $page, $rowLimit );
                $aamaps = null;
            }

            $page = 1;
            $queryOptions->setPage( $page, $rowLimit );

            while ( sizeof( ($articles = $oarticles->select( $queryOptions )) ) ) {
                $litearticles->insert( $articles );
                $page++;
                $queryOptions->setPage( $page, $rowLimit );
                $articles = null;
            }


            $page = 1;
            $queryOptions->setPage( $page, $rowLimit );

            while ( sizeof( ($authors = $oauthors->select( $queryOptions )) ) ) {
                $liteauthors->insert( $authors );
                $page++;
                $queryOptions->setPage( $page, $rowLimit );
                $authors = null;
            }

            $page = 1;
            $queryOptions->setPage( $page, $rowLimit );

            while ( sizeof( ($images = $oimages->select( $queryOptions )) ) ) {
                $liteimages->insert( $images );
                $page++;
                $queryOptions->setPage( $page, $rowLimit );
                $images = null;
            }

            $page = 1;
            $queryOptions->setPage( $page, $rowLimit );

            while ( sizeof( ($samaps = $osamaps->select( $queryOptions )) ) ) {
                $litesamaps->insert( $samaps );
                $page++;
                $queryOptions->setPage( $page, $rowLimit );
                $samaps = null;
            }

            $page = 1;
            $queryOptions->setPage( $page, $rowLimit );

            try {
                while ( sizeof( ($sections = $osections->select( $queryOptions )) ) ) {
                    $litesections->insert( $sections );
                    $page++;
                    $queryOptions->setPage( $page, $rowLimit );
                    $sections = null;
                }
            }
            catch ( PDOException $e ) {
                throw $e;
            }

            $page = 1;
            $queryOptions->setPage( $page, $rowLimit );

            while ( sizeof( ($websites = $owebsites->select( $queryOptions )) ) ) {
                $litewebsites->insert( $websites );
                $page++;
                $queryOptions->setPage( $page, $rowLimit );
                $websites = null;
            }

            $page = 1;
            $queryOptions->setPage( $page, $rowLimit );

            while ( sizeof( ($wsmaps = $owsmaps->select( $queryOptions )) ) ) {
                $litewsmaps->insert( $wsmaps );
                $page++;
                $queryOptions->setPage( $page, $rowLimit );
                $wsmaps = null;
            }
        }
        else {
            // probably should throw an exception or something here
            return false;
        }

        $newname = str_replace( '-tmp-', '', $tempname );

        $offset = 0;
        $pos = 0;

        while ( ($pos = strpos( $newname, '-', $offset )) !== false ) {
            $offset = $pos + 1;
        }

        $offset--;
        $pos = strpos( $newname, '.' );

        $newname = substr_replace( $newname, '', $offset, $pos - $offset );

        if ( rename( $tempname, $newname ) ) {
            return $newname;
        }

        return false;
    }

    /**
     * Delete the Onpub schema.
     *
     * Calling this method will delete all Onpub content and schema in the
     * PDO-connected database! Use with caution.
     *
     * @return mixed true if the schema was successfully deleted. An array
     * of PDOException objects will be returned if any errors occured.
     */
    public function delete()
    {
        $sqlfile = array();
        $line = 0;
        $exceptions = array();

        switch ( $this->pdo->getAttribute( PDO::ATTR_DRIVER_NAME ) ) {
            case "mysql":
            $sqlfile = file( OnpubDatabase::MYSQL_TABLES_DELETE_FILE );
            break;
            case "sqlite":
            $sqlfile = file( OnpubDatabase::SQLITE_TABLES_DELETE_FILE );
            break;
        }

        // advance past all comments
        while ( strpos( $sqlfile[$line], '--' ) !== false ) {
            $line++;

            while ( $sqlfile[$line] == "\n" ) {
                $line++;
            }
        }

        for ( $i = $line; $i < sizeof( $sqlfile ); $i++ ) {
            $query = '';

            while ( strpos( $sqlfile[$i], ';' ) === false ) {
                $query .= $sqlfile[$i];
                $i++;
            }

            $query .= $sqlfile[$i];

            if ( ($i + 1) < sizeof( $sqlfile ) ) {
                while ( $sqlfile[$i + 1] == "\n" ) {
                    $i++;
                }
            }

            $result = null; $result = $this->pdo->exec( $query );

            try {
                OnpubDatabase::verifyExec( $this->pdo, $result, false );
            }
            catch ( PDOException $e ) {
                $exceptions[] = $e;
            }
        }

        if ( sizeof( $exceptions ) ) {
            return $exceptions;
        }

        return true;
    }

    /**
     * Install the {@link http://onpubco.com/pdfs/onpub_schema.pdf Onpub schema}.
     *
     * Calling this method will install the Onpub tables in the PDO-connected
     * database.
     *
     * @return mixed true if the schema was successfully installed. An array
     * of PDOException objects will be returned if any errors occured.
     */
    public function install()
    {
        $sqlfile = array();
        $line = 0;
        $exceptions = array();

        switch ( $this->pdo->getAttribute( PDO::ATTR_DRIVER_NAME ) ) {
            case "mysql":
            $sqlfile = file( OnpubDatabase::MYSQL_TABLES_CREATE_FILE );
            break;
            case "sqlite":
            $sqlfile = file( OnpubDatabase::SQLITE_TABLES_CREATE_FILE );
            break;
        }

        // advance past all comments
        while ( strpos( $sqlfile[$line], '--' ) !== false ) {
            $line++;

            while ( $sqlfile[$line] == "\n" ) {
                $line++;
            }
        }

        for ( $i = $line; $i < sizeof( $sqlfile ); $i++ ) {
            $query = '';

            while ( strpos( $sqlfile[$i], ';' ) === false ) {
                $query .= $sqlfile[$i];
                $i++;
            }

            $query .= $sqlfile[$i];

            if ( ($i + 1) < sizeof( $sqlfile ) ) {
                while ( $sqlfile[$i + 1] == "\n" ) {
                    $i++;
                }
            }

            $result = null; $result = $this->pdo->exec( $query );

            try {
                OnpubDatabase::verifyExec( $this->pdo, $result, false );
            }
            catch ( PDOException $e ) {
                $exceptions[] = $e;
            }
        }

        if ( sizeof( $exceptions ) ) {
            return $exceptions;
        }

        return true;
    }

    /**
     * Check the status of the Onpub schema.
     *
     * @return mixed true if the schema is properly installed. An array
     * of PDOException objects will be returned if the schema is incomplete or
     * not installed.
     */
    public function status()
    {
        $oaamaps = new OnpubAAMaps( $this->pdo );
        $oarticles = new OnpubArticles( $this->pdo );
        $oauthors = new OnpubAuthors( $this->pdo );
        //$ocomments = new OnpubComments( $this->pdo );
        $oimages = new OnpubImages( $this->pdo );
        $osamaps = new OnpubSAMaps( $this->pdo );
        $osections = new OnpubSections( $this->pdo );
        $owebsites = new OnpubWebsites( $this->pdo );
        $owsmaps = new OnpubWSMaps( $this->pdo );
        $queryOptions = new OnpubQueryOptions( $this->pdo );
        $queryOptions->setPage( 1, 1 );
        $exceptions = array();

        try { $oaamaps->select( $queryOptions ); }
        catch ( PDOException $e ) { $exceptions[] = $e; }

        try { $oarticles->select( $queryOptions ); }
        catch ( PDOException $e ) { $exceptions[] = $e; }

        try { $oauthors->select( $queryOptions ); }
        catch ( PDOException $e ) { $exceptions[] = $e; }

        //try { $ocomments->select( $queryOptions ); }
        //catch ( PDOException $e ) { $exceptions[] = $e; }

        try { $oimages->select( $queryOptions ); }
        catch ( PDOException $e ) { $exceptions[] = $e; }

        try { $osamaps->select( $queryOptions ); }
        catch ( PDOException $e ) { $exceptions[] = $e; }

        try { $osections->select( $queryOptions ); }
        catch ( PDOException $e ) { $exceptions[] = $e; }

        try { $owebsites->select( $queryOptions ); }
        catch ( PDOException $e ) { $exceptions[] = $e; }

        try { $owsmaps->select( $queryOptions ); }
        catch ( PDOException $e ) { $exceptions[] = $e; }

        if ( sizeof( $exceptions ) ) {
            return $exceptions;
        }

        return true;
    }

    /**
     * Verify the results of a call to {@link PHP_MANUAL#function.pdostatement-execute PDOStatement->execute()}.
     *
     * Used internally to verify whether or not a PDOStatement->execute() call was
     * successful or not. If the call returned false then an exception is
     * thrown with an error message and error code, explaining what went wrong.
     * If the execute() call fails during a running database transaction,
     * {@link PHP_MANUAL#function.pdo-rollback PDOStatement->rollback()} is called to
     * roll back the transaction to put the database back in the state it was
     * before the error occured; then the appropriate exception is thrown.
     *
     * @param PDO $pdo The PDO object which called {@link PHP_MANUAL#function.pdo-prepare prepare()}.
     * @param mixed $result The value execute() returned when it was called.
     * @param bool $isTransaction true if execute() was called during a running
     *                            database transaction, false otherwise.
     * @param array $errorInfo The array returned by {@link PHP_MANUAL#function.pdostatement-errorinfo PDOStatement->errorInfo()}.
     * @return void
     * @throws PDOException if the execute() call failed.
     */
    public static function verifyExecute( PDO $pdo, $result, $isTransaction, $errorInfo )
    {
        if ( $isTransaction ) {
            if ( !$result ) {
                $status = $pdo->rollBack();

                if ( !$status ) {
                    $errorInfo = $pdo->errorInfo();
                    $e = new PDOException( $errorInfo[2], $errorInfo[1] );
                    $e->errorInfo = $errorInfo;
                    throw $e;
                }

                $e = new PDOException( $errorInfo[2], $errorInfo[1] );
                $e->errorInfo = $errorInfo;
                throw $e;
            }
        }
        else {
            if ( !$result ) {
                $e = new PDOException( $errorInfo[2], $errorInfo[1] );
                $e->errorInfo = $errorInfo;
                throw $e;
            }
        }
    }

    /**
     * Verify the results of a call to {@link PHP_MANUAL#function.pdo-exec PDO->exec()}.
     *
     * Used internally to verify whether or not a PDO->exec() call was
     * successful or not. If the call returned false then an exception is
     * thrown with an error message and error code, explaining what went wrong.
     * If the exec() call fails during a running database transaction,
     * {@link PHP_MANUAL#function.pdo-rollback PDO->rollback()} is called to
     * roll back the transaction to put the database back in the state it was
     * before the error occured; then the appropriate exception is thrown.
     *
     * @param PDO $pdo The PDO object which called exec().
     * @param mixed $result The value exec() returned when it was called.
     * @param bool $isTransaction true if exec() was called during a running
     *                            database transaction, false otherwise.
     * @return void
     * @throws PDOException if the exec() call failed.
     */
    public static function verifyExec( PDO $pdo, $result, $isTransaction )
    {
        if ( $isTransaction ) {
            if ( $result === false ) {
                $errorInfo = $pdo->errorInfo();
                $status = $pdo->rollBack();

                if ( !$status ) {
                    $errorInfo = $pdo->errorInfo();
                    $e = new PDOException( $errorInfo[2], $errorInfo[1] );
                    $e->errorInfo = $errorInfo;
                    throw $e;
                }

                $e = new PDOException( $errorInfo[2], $errorInfo[1] );
                $e->errorInfo = $errorInfo;
                throw $e;
            }
        }
        else {
            if ( $result === false ) {
                $errorInfo = $pdo->errorInfo();
                $e = new PDOException( $errorInfo[2], $errorInfo[1] );
                $e->errorInfo = $errorInfo;
                throw $e;
            }
        }
    }

    /**
     * Verify the results of a call to {@link PHP_MANUAL#function.pdo-query PDO->query()}.
     *
     * Used internally to verify whether or not a PDO->query() call was
     * successful or not. If the call returned false then an exception is
     * thrown with an error message and error code, explaining what went wrong.
     * If the query() call fails during a running database transaction,
     * {@link PHP_MANUAL#function.pdo-rollback PDO->rollback()} is called to
     * roll back the transaction to put the database back in the state it was
     * before the error occured; then the appropriate exception is thrown.
     *
     * @param PDO $pdo The PDO object which called query().
     * @param mixed $result The value query() returned when it was called.
     * @param bool $isTransaction true if query() was called during a running
     *                            database transaction, false otherwise.
     * @return void
     * @throws PDOException if the query() call failed.
     */
    public static function verifyQuery( PDO $pdo, $result, $isTransaction )
    {
        if ( $isTransaction ) {
            if ( !$result ) {
                $errorInfo = $pdo->errorInfo();
                $status = $pdo->rollBack();

                if ( !$status ) {
                    $errorInfo = $pdo->errorInfo();
                    $e = new PDOException( $errorInfo[2], $errorInfo[1] );
                    $e->errorInfo = $errorInfo;
                    throw $e;
                }

                $e = new PDOException( $errorInfo[2], $errorInfo[1] );
                $e->errorInfo = $errorInfo;
                throw $e;
            }
        }
        else {
            if ( !$result ) {
                $errorInfo = $pdo->errorInfo();
                $e = new PDOException( $errorInfo[2], $errorInfo[1] );
                $e->errorInfo = $errorInfo;
                throw $e;
            }
        }
    }

    /**
     * Verify the results of a call to {@link PHP_MANUAL#function.pdo-beginTransaction PDO->beginTransaction()} or {@link PHP_MANUAL#function.pdo-commit PDO->commit()}.
     *
     * Used internally to verify whether or not a PDO->beginTransaction() or a
     * PDO->rollback() call was successful or not. If the call returned false
     * then an exception is thrown with an error message and error code,
     * explaining what went wrong.
     *
     * @param PDO $pdo The PDO object which called beginTransaction() or rollback().
     * @param mixed $result The value beginTransaction() or rollback() returned when it was called.
     * @return void
     * @throws PDOException if the beginTransaction() or rollback() call failed.
     */
    public static function verifyTransaction( PDO $pdo, $result )
    {
        if ( !$result ) {
            $errorInfo = $pdo->errorInfo();
            $e = new PDOException( $errorInfo[2], $errorInfo[1] );
            $e->errorInfo = $errorInfo;
            throw $e;
        }
    }

    /**
     * Verify the results of a call to {@link PHP_MANUAL#function.pdo-prepare PDO->prepare()}.
     *
     * Used internally to verify whether or not a PDO->prepare() call was
     * successful or not. If the call returned false then an exception is
     * thrown with an error message and error code, explaining what went wrong.
     * If the prepare() call fails during a running database transaction,
     * {@link PHP_MANUAL#function.pdo-rollback PDO->rollback()} is called to
     * roll back the transaction to put the database back in the state it was
     * before the error occured; then the appropriate exception is thrown.
     *
     * @param PDO $pdo The PDO object which called prepare().
     * @param mixed $result The value prepare() returned when it was called.
     * @param bool $isTransaction true if prepare() was called during a running
     *                            database transaction, false otherwise.
     * @return void
     * @throws PDOException if the prepare() call failed.
     */
    public static function verifyPrepare( PDO $pdo, $result, $isTransaction )
    {
        if ( $isTransaction ) {
            if ( $result === false ) {
                $errorInfo = $pdo->errorInfo();
                $status = $pdo->rollBack();

                if ( !$status ) {
                    $errorInfo = $pdo->errorInfo();
                    $e = new PDOException( $errorInfo[2], $errorInfo[1] );
                    $e->errorInfo = $errorInfo;
                    throw $e;
                }

                $e = new PDOException( $errorInfo[2], $errorInfo[1] );
                $e->errorInfo = $errorInfo;
                throw $e;
            }
        }
        else {
            if ( $result === false ) {
                $errorInfo = $pdo->errorInfo();
                $e = new PDOException( $errorInfo[2], $errorInfo[1] );
                $e->errorInfo = $errorInfo;
                throw $e;
            }
        }
    }

    /**
     * Decode a UTF8-encoded string to a latin1-encoded string.
     *
     * @param string $in_str UTF8-encoded string.
     * @return string latin1-encoded string.
     */
    public static function utf8Decode($in_str)
    {
       // utf8Decode is courtesy nospam@jra.nu and was found
       // at: http://us4.php.net/utf8-decode in the comments section
       // Replace ? with a unique string
       $new_str = str_replace("?", "q0u0e0s0t0i0o0n", $in_str);

       // Try the utf8_decode
       $new_str=utf8_decode($new_str);

       // if it contains ? marks
       if (strpos($new_str,"?") !== false)
       {
           // Something went wrong, set new_str to the original string.
           $new_str=$in_str;
       }
       else
       {
           // If not then all is well, put the ?-marks back where is belongs
           $new_str = str_replace("q0u0e0s0t0i0o0n", "?", $new_str);
       }

       return $new_str;
    }
}

?>
