<?php

/**
 * @author {@link mailto:corey@onpubco.com Corey HM Taylor}
 * @copyright Onpub (TM) Copyright (C) 2007, Onpubco
 * {@link http://onpubco.com/}
 * @license http://www.gnu.org/copyleft/gpl.html GNU General Public License
 * Version 2
 * @package onpubgui
 * @version 0.8.6
 */
class OnpubEditArticle
{
    private $pdo;
    private $oarticle;
    private $tidyConfig;
    private $nltobr;
    private $delbr;

    function __construct( PDO $pdo, OnpubArticle $oarticle, $tidyConfig = array(), $nltobr = "0", $delbr = "0" )
    {
        $this->pdo = $pdo;
        $this->oarticle = $oarticle;
        $this->tidyConfig = $tidyConfig;
        $this->nltobr = $nltobr;
        $this->delbr = $delbr;
    }

    public function display()
    {
        $oarticles = new OnpubArticles( $this->pdo );
        $oaamaps = new OnpubAAMaps( $this->pdo );
        $oimages = new OnpubImages( $this->pdo );
        $owebsites = new OnpubWebsites( $this->pdo );
        $osamaps = new OnpubSAMaps( $this->pdo );
        $osections = new OnpubSections( $this->pdo );

        try {
            $queryOptions = new OnpubQueryOptions();
            $queryOptions->includeAuthors = true;
            $this->oarticle = $oarticles->get( $this->oarticle->ID, $queryOptions );

            $queryOptions = new OnpubQueryOptions();
            $queryOptions->orderBy = "fileName";
            $queryOptions->order = "ASC";
            $images = $oimages->select( $queryOptions );

            $queryOptions = new OnpubQueryOptions();
            $queryOptions->orderBy = "name";
            $queryOptions->order = "ASC";
            $websites = $owebsites->select( $queryOptions );

            $queryOptions = new OnpubQueryOptions();
            $samaps = $osamaps->select( $queryOptions, null, $this->oarticle->ID );
        }
        catch ( PDOException $e ) {
            throw $e;
        }

        $author = $this->oarticle->authors;

        if ( sizeof( $author ) ) {
            $author = $author[0];
        }
        else {
            $author = new OnpubAuthor();
        }

        $widget = new OnpubWidgetHeader( "Article - " . $this->oarticle->title );
        $widget->display();

        include("gui/fckeditor/fckeditor.php");

        echo '<form action="index.php" method="post">' . "\n";

        echo '<table cellspacing="0" cellpadding="5" border="0">' . "\n";

        echo '<tr>' . "\n";
        echo '<td class="buttons"><a href="javascript:submitForm();"><img src="' . ONPUBGUI_IMAGE_DIRECTORY . 'save.png" width="60" height="25" border="0" alt="Save" title="Save" /></a> <a href="javascript:deleteArticle();"><img src="' . ONPUBGUI_IMAGE_DIRECTORY . 'delete.png" width="60" height="25" border="0" alt="Delete" title="Delete" /></a> <a href="javascript:viewArticle();"><img src="' . ONPUBGUI_IMAGE_DIRECTORY . 'view.png" width="60" height="25" border="0" alt="View" title="View" /></a></td>' . "\n";
        echo '</tr>' . "\n";

        echo '<tr>' . "\n";
        echo '<td><b>Title</b><br /><input type="text" maxlength="255" size="75" name="title" value="' . htmlentities( $this->oarticle->title ) . '" /></td>' . "\n";
        echo '</tr>' . "\n";

        echo '<tr>' . "\n";
        echo '<td><b>Author</b><br /><input type="text" maxlength="255" size="75" name="displayAs" value="' . htmlentities( $author->displayAs ) . '" /></td>' . "\n";
        echo '</tr>' . "\n";

        echo '<tr>' . "\n";

        echo '<td><b>Content</b><br />' . "\n";

        $oFCKeditor = new FCKeditor('content');
        $oFCKeditor->BasePath = 'gui/fckeditor/';
        $oFCKeditor->Value = $this->oarticle->content;
        $oFCKeditor->Width = '830';
        $oFCKeditor->Height = '330';
        $oFCKeditor->Config['CustomConfigurationsPath'] = '../../js/fckconfig.js';
        $oFCKeditor->Create();

/*
        if ( $this->nltobr == "1" ) {
            echo '<input type="checkbox" id="id_nltobr" name="nltobr" value="1" checked="checked" /> <label for="id_nltobr">Automatically insert a break tag for each line break</label><br />' . "\n";
        }
        else {
            echo '<input type="checkbox" id="id_nltobr" name="nltobr" value="1" /> <label for="id_nltobr">Automatically insert a break tag for each line break</label><br />' . "\n";
        }

        if ( $this->delbr == "1" ) {
            echo '<input type="checkbox" id="id_delbr" name="delbr" value="1" checked="checked" /> <label for="id_delbr">Delete all break tags</label><br />' . "\n";
        }
        else {
            echo '<input type="checkbox" id="id_delbr" name="delbr" value="1" /> <label for="id_delbr">Delete all break tags</label><br />' . "\n";
        }
*/

        echo '</td>' . "\n";
        echo '</tr>' . "\n";

        if ( function_exists( "tidy_repair_string" ) ) {
            echo '<tr>' . "\n";
            echo '<td><b>HTML Tidy</b><br />' . "\n";

            if ( $this->tidyConfig['markup'] ) {
                echo '<input type="checkbox" id="id_markup" name="markup" value="1" checked="checked" /> <label for="id_markup">Tidy HTML in Content</label><br />' . "\n";
            }
            else {
                echo '<input type="checkbox" id="id_markup" name="markup" value="1" /> <label for="id_markup">Tidy HTML in Content</label><br />' . "\n";
            }

            echo '</td>' . "\n";
            echo '</tr>' . "\n";
        }

        echo '<tr>' . "\n";
        echo '<td><b>ID</b><br />' . $this->oarticle->ID . '</td>' . "\n";
        echo '</tr>' . "\n";

        $widget = new OnpubWidgetDateCreated( $this->oarticle->getCreated() );
        $widget->display();

        $modified = $this->oarticle->getModified();

        echo '<tr>' . "\n";
        echo '<td><b>Modified</b><br />' . $modified->format( 'M j, Y g:i:s A' ) . '</td>' . "\n";
        echo '</tr>' . "\n";

        if ( $this->oarticle->url ) {
            $go = ' <b><a href="' . $this->oarticle->url . '" target="_blank"><img src="gui/icons/world_go.png" border="0" align="top" alt="Go" title="Go" width="16" height="16" /></a></b>';
        }
        else {
            $go = '';
        }

        echo '<tr>' . "\n";
        echo '<td><b>URL</b><br /><input type="text" maxlength="255" size="75" name="url" value="' . htmlentities( $this->oarticle->url ) . '" />' . $go . '</td>' . "\n";
        echo '</tr>' . "\n";
/*
        $widget = new OnpubWidgetImages( "Image", $this->oarticle->imageID, $images );
        $widget->display();
*/
        $widget = new OnpubWidgetSections( null, $websites, $osections, $samaps );
        $widget->display();

        echo '</table>' . "\n";

        echo '<div><input type="hidden" name="ID" value="' . $this->oarticle->ID . '" /></div>' . "\n";
        echo '<div><input type="hidden" name="imageID" value="' . $this->oarticle->imageID . '" /></div>' . "\n";
        echo '<div><input type="hidden" name="authorID" value="' . $author->ID . '" /></div>' . "\n";
        echo '<div><input type="hidden" name="authorImageID" value="' . $author->imageID . '" /></div>' . "\n";
        echo '<div><input type="hidden" name="lastDisplayAs" value="' . htmlentities( $author->displayAs ) . '" /></div>' . "\n";
        echo '<div><input type="hidden" name="onpub" value="EditArticleProcess" /></div>' . "\n";

        echo '</form>' . "\n";

        $widget = new OnpubWidgetFooter();
        $widget->display();
    }

    public function validate()
    {
        if ( !$this->oarticle->title ) {
            $this->oarticle->title = null;
            return false;
        }

        return true;
    }

    public function process()
    {
        $oarticles = new OnpubArticles( $this->pdo );

        $content = OnpubDatabase::utf8Decode( $this->oarticle->content );

        if ( $this->nltobr == "1" ) {
            $content = nl2br( $content );
        }

        if ( $this->delbr == "1" ) {
            $content = str_ireplace( "<br>", "", $content );
            $content = str_ireplace( "<br />", "", $content );
        }

        if ( function_exists( "tidy_repair_string" ) ) {
            if ( $this->tidyConfig['markup'] ) {
                $content = tidy_repair_string( $content, $this->tidyConfig, "latin1" );
            }
        }

        $this->oarticle->content = $content;

        try {
            $oarticles->update( $this->oarticle, true );
        }
        catch ( PDOException $e ) {
            throw $e;
        }
    }

    public function delete()
    {
        $oarticles = new OnpubArticles( $this->pdo );

        try {
            $oarticles->delete( $this->oarticle->ID );
        }
        catch ( PDOException $e ) {
            throw $e;
        }
    }
}

?>
