<?php

/**
 * @author {@link mailto:corey@onpubco.com Corey HM Taylor}
 * @copyright Onpub (TM) Copyright (C) 2007, Onpubco
 * {@link http://onpubco.com/}
 * @license http://www.gnu.org/copyleft/gpl.html GNU General Public License
 * Version 2
 * @package onpubgui
 * @version 0.8.6
 */
class OnpubEditImage
{
    private $pdo;
    private $oimage;
    private $oldImageFileName;

    function __construct( PDO $pdo, OnpubImage $oimage, $oldImageFileName = null )
    {
        $this->pdo = $pdo;
        $this->oimage = $oimage;
        $this->oldImageFileName = $oldImageFileName;
    }

    public function display()
    {
        $oimages = new OnpubImages( $this->pdo );
        $owebsites = new OnpubWebsites( $this->pdo );
        $imageFileSize = null;
        $imageWidth = null;
        $imageHeight = null;
        $imageDimensions = null;
        $imageFileInfo = null;
        $fileExists = false;

        try {
            $this->oimage = $oimages->get( $this->oimage->ID );
            $website = $owebsites->get( $this->oimage->websiteID );
        }
        catch ( PDOException $e ) {
            throw $e;
        }

        if ( $fileExists = file_exists( $website->imagesDirectory . $this->oimage->fileName ) ) {
            if ( function_exists( "getimagesize" ) ) {
                $imageDimensions = getimagesize( $website->imagesDirectory . $this->oimage->fileName );
            }

            $imageFileInfo = stat( $website->imagesDirectory . $this->oimage->fileName );
        }

        if ( $imageFileInfo ) {
            $imageFileSize = $imageFileInfo[7];
        }

        if ( $imageDimensions ) {
            $imageWidth = $imageDimensions[0];
            $imageHeight = $imageDimensions[1];
        }

        $widget = new OnpubWidgetHeader( "Image - " . $this->oimage->fileName );
        $widget->display();

        echo '<form action="index.php" method="post">' . "\n";

        echo '<table border="0" cellpadding="5" cellspacing="0">' . "\n";

        echo '<tr>' . "\n";
        echo '<td class="buttons"><a href="javascript:submitForm();"><img src="' . ONPUBGUI_IMAGE_DIRECTORY . 'save.png" border="0" alt="" /></a> <a href="javascript:deleteImage();"><img src="' . ONPUBGUI_IMAGE_DIRECTORY . 'delete.png" border="0" alt="" /></a></td>' . "\n";
        echo '</tr>' . "\n";

        echo '<tr>' . "\n";
        echo '<td><b>ID</b><br />' . $this->oimage->ID . '</td>' . "\n";
        echo '</tr>' . "\n";

        echo '<tr>' . "\n";
        echo '<td><b>Created</b><br />' . $this->oimage->getCreated()->format( 'M j, Y g:i:s A' ) . '' . "\n";
        echo '</tr>' . "\n";

        echo '<tr>' . "\n";
        echo '<td><b>Modified</b><br />' . $this->oimage->getModified()->format( 'M j, Y g:i:s A' ) . '' . "\n";
        echo '</tr>' . "\n";

        echo '<tr>' . "\n";
        echo '<td><b>File Name</b><br /><input type="text" maxlength="255" size="' . 30 . '" name="fileName" value="' . htmlentities( $this->oimage->fileName ) . '" /></td>' . "\n";
        echo '</tr>' . "\n";

        if ( @fopen( $website->imagesURL . rawurlencode( $this->oimage->fileName ), 'r' ) ) {
            echo '<tr>' . "\n";
            echo '<td><b>URL</b><br /><a href="' . $website->imagesURL . $this->oimage->fileName . '" target="_blank">' . $website->imagesURL . $this->oimage->fileName . '</a></td>' . "\n";
            echo '</tr>' . "\n";

            echo '<tr>' . "\n";
            echo '<td>' . "\n";

            if ( $imageWidth && $imageHeight ) {
                echo '<a href="' . $website->imagesURL . $this->oimage->fileName . '" target="_blank"><img src="' . $website->imagesURL . $this->oimage->fileName . '" width="' . $imageWidth . '" height="' . $imageHeight . '" alt="' . $this->oimage->fileName . '" title="' . $this->oimage->fileName . '" border="0" /></a>' . "\n";
            }
            else {
                echo '<a href="' . $website->imagesURL . $this->oimage->fileName . '" target="_blank"><img src="' . $website->imagesURL . $this->oimage->fileName . '" alt="' . $this->oimage->fileName . '" title="' . $this->oimage->fileName . '" border="0" /></a>' . "\n";
            }

            echo '</td>' . "\n";
            echo '</tr>' . "\n";
        }
        else {
            echo '<tr>' . "\n";
            echo '<td><b>URL</b><br /><a href="' . $website->imagesURL . $this->oimage->fileName . '" target="_blank">' . $website->imagesURL . $this->oimage->fileName . '</a> <img src="gui/icons/picture_error.png" align="top" width="16" height="16" alt="Image not found" title="Image not found" /><br /><span class="tip">Tip:</span> make sure the Images URL of Website <a href="index.php?onpub=EditWebsite&amp;websiteID=' . $website->ID . '">' . $website->name . '</a> is setup correctly.</td>' . "\n";
            echo '</tr>' . "\n";
        }

        echo '<tr>' . "\n";
        echo '<td><b>Description</b><br /><input type="text" maxlength="255" size="' . 30 . '" name="description" value="' . htmlentities( $this->oimage->description ) . '" /></td>' . "\n";
        echo '</tr>' . "\n";

        echo '<tr>' . "\n";
        echo '<td><b>Website</b><br /><a href="index.php?onpub=EditWebsite&amp;websiteID=' . $website->ID . '" title="Edit">' . $website->name . '</a></td>' . "\n";
        echo '</tr>' . "\n";

        if ( $fileExists ) {
            echo '<tr>' . "\n";
            echo '<td><b>File Path</b><br />' . $website->imagesDirectory . $this->oimage->fileName . ' (on <i>' . $_SERVER['SERVER_NAME'] . '</i>)</td>' . "\n";
            echo '</tr>' . "\n";

            echo '<tr>' . "\n";
            echo '<td>' . "\n";
            echo '<b>Width</b><br />' . "\n";
            echo $imageWidth . 'px' . "\n";
            echo '</td>' . "\n";
            echo '</tr>' . "\n";

            echo '<tr>' . "\n";
            echo '<td>' . "\n";
            echo '<b>Height</b><br />' . "\n";
            echo $imageHeight . 'px' . "\n";
            echo '</td>' . "\n";
            echo '</tr>' . "\n";

            echo '<tr>' . "\n";
            echo '<td>' . "\n";
            echo '<b>File Size</b><br />' . "\n";

            if ( $imageFileSize >= 1024 ) {
                echo round( ($imageFileSize / 1024) ) . ' KB (' . $imageFileSize . ' bytes)' . "\n";
            }
            else {
                echo $imageFileSize . ' bytes' . "\n";
            }

            echo '</td>' . "\n";
            echo '</tr>' . "\n";
        }

        echo '</table>' . "\n";

        echo '<div><input type="hidden" name="onpub" value="EditImageProcess" /></div>' . "\n";
        echo '<div><input type="hidden" name="imageID" value="' . $this->oimage->ID . '" /></div>' . "\n";
        echo '<div><input type="hidden" name="oldImageFileName" value="' . htmlentities( $this->oimage->fileName ) . '" /></div>' . "\n";

        echo '</form>' . "\n";

        $widget = new OnpubWidgetFooter();
        $widget->display();
    }

    public function validate()
    {
        return true;
    }

    public function process()
    {
        $oimages = new OnpubImages( $this->pdo );
        $owebsites = new OnpubWebsites( $this->pdo );

        $image = $oimages->get( $this->oimage->ID );
        $website = $owebsites->get( $image->websiteID );

        if ( $this->oimage->fileName != $this->oldImageFileName ) {
            if ( file_exists( $website->imagesDirectory . $this->oldImageFileName ) ) {
                rename( $website->imagesDirectory . $this->oldImageFileName, $website->imagesDirectory . $this->oimage->fileName );
            }
        }

        try {
            $oimages->update( $this->oimage );
        }
        catch ( PDOException $e ) {
            throw $e;
        }
    }

    public function delete()
    {
        $oimages = new OnpubImages( $this->pdo );
        $owebsites = new OnpubWebsites( $this->pdo );
        $this->oimage = $oimages->get( $this->oimage->ID );
        $website = $owebsites->get( $this->oimage->websiteID );

        try {
            $oimages->delete( $this->oimage->ID );
        }
        catch ( PDOException $e ) {
            throw $e;
        }

        if ( file_exists( $website->imagesDirectory . $this->oimage->fileName ) ) {
            unlink( $website->imagesDirectory . $this->oimage->fileName );
        }
    }
}

?>
