<?php

/**
 * @author {@link mailto:corey@onpubco.com Corey HM Taylor}
 * @copyright Onpub (TM) Copyright (C) 2007, Onpubco
 * {@link http://onpubco.com/}
 * @license http://www.gnu.org/copyleft/gpl.html GNU General Public License
 * Version 2
 * @package onpubgui
 * @version 0.8.6
 */
class OnpubEditSection
{
    private $pdo;
    private $osection;

    function __construct( PDO $pdo, OnpubSection $osection )
    {
        $this->pdo = $pdo;
        $this->osection = $osection;
    }

    public function display()
    {
        $osections = new OnpubSections( $this->pdo );
        $owebsites = new OnpubWebsites( $this->pdo );
        $oarticles = new OnpubArticles( $this->pdo );
        $oimages = new OnpubImages( $this->pdo );
        $osamaps = new OnpubSAMaps( $this->pdo );
        $queryOptions = new OnpubQueryOptions();
        $queryOptions->includeArticles = true;
        $queryOptions->includeContent = false;

        try {
            $this->osection = $osections->get( $this->osection->ID, $queryOptions );

            if ( $this->osection->parentID ) {
                $parent = $osections->get( $this->osection->parentID );
            }

            $website = $owebsites->get( $this->osection->websiteID );
            $numOfArticles = $oarticles->count();

            $queryOptions = new OnpubQueryOptions();
            $queryOptions->orderBy = "name";
            $queryOptions->order = "ASC";
            $websites = $owebsites->select( $queryOptions );

            $joinedWebsites = array();

            $queryOptions = new OnpubQueryOptions();
            $queryOptions->orderBy = "fileName";
            $queryOptions->order = "ASC";
            $images = $oimages->select( $queryOptions );

/*
            foreach ( $websites as $site ) {
                $joinedWebsites[] = $owebsites->get( $site->websiteID, true, false, null, null, null, null, false );
            }
*/
        }
        catch ( PDOException $e ) {
            throw $e;
        }

        $widget = new OnpubWidgetHeader( "Section - " . $this->osection->name );
        $widget->display();

        echo '<form action="index.php" method="post">' . "\n";

        echo '<table border="0" cellpadding="5" cellspacing="0">' . "\n";
        echo '<tr>' . "\n";

        if ( $numOfArticles ) {
            echo '<td class="buttons"><a href="javascript:selectAll( articleList ); submitForm();"><img src="' . ONPUBGUI_IMAGE_DIRECTORY . 'save.png" border="0" alt="" /></a> <a href="javascript:deleteSection();"><img src="' . ONPUBGUI_IMAGE_DIRECTORY . 'delete.png" border="0" alt="" /></a></td>' . "\n";
        }
        else {
            echo '<td class="buttons"><a href="javascript:submitForm();"><img src="' . ONPUBGUI_IMAGE_DIRECTORY . 'save.png" border="0" alt="" /></a> <a href="javascript:deleteSection();"><img src="' . ONPUBGUI_IMAGE_DIRECTORY . 'delete.png" border="0" alt="" /></a></td>' . "\n";
        }

        echo '</tr>' . "\n";

        echo '<tr>' . "\n";
        echo '<td><b>ID</b><br />' . $this->osection->ID . '</td>' . "\n";
        echo '</tr>' . "\n";

        echo '<tr>' . "\n";
        echo '<td><b>Created</b><br />' . $this->osection->getCreated()->format( 'M j, Y g:i:s A' ) . '' . "\n";
        echo '</tr>' . "\n";

        echo '<tr>' . "\n";
        echo '<td><b>Modified</b><br />' . $this->osection->getModified()->format( 'M j, Y g:i:s A' ) . '' . "\n";
        echo '</tr>' . "\n";

        echo '<tr>' . "\n";

        if ( $this->osection->name === null ) {
            echo '<td><b>Name</b><br /><input type="text" maxlength="255" size="75" name="name" value="" /> <img src="gui/icons/exclamation.png" align="top" alt="Required field" title="Required field" /></td>' . "\n";
        }
        else {
            echo '<td><b>Name</b><br /><input type="text" maxlength="255" size="75" name="name" value="' . htmlentities( $this->osection->name ) . '" /></td>' . "\n";
        }

        echo '</tr>' . "\n";

        if ( $this->osection->url ) {
            $go = ' <b><a href="' . $this->osection->url . '" target="_blank"><img src="gui/icons/world_go.png" border="0" align="top" alt="Go" title="Go" width="16" height="16" /></a></b>';
        }
        else {
            $go = '';
        }

        echo '<tr>' . "\n";
        echo '<td><b>URL</b><br /><input type="text" maxlength="255" size="75" name="url" value="' . htmlentities( $this->osection->url ) . '" />' . $go . '</td>' . "\n";
        echo '</tr>' . "\n";

        $widget = new OnpubWidgetImages( "Icon", $this->osection->imageID, $images, $website );
        $widget->display();

        if ( $this->osection->parentID ) {
            echo '<tr>' . "\n";
            echo '<td><b>Parent Section</b><br /><a href="index.php?onpub=EditSection&amp;sectionID=' . $parent->ID . '" title="Edit">' . $parent->name . '</a></td>' . "\n";
            echo '</tr>' . "\n";
        }
        else {
            echo '<tr>' . "\n";
            echo '<td><b>Parent Section</b><br />None</td>' . "\n";
            echo '</tr>' . "\n";
        }

        echo '<tr>' . "\n";
        echo '<td><b>Website</b><br /><a href="index.php?onpub=EditWebsite&amp;websiteID=' . $website->ID . '" title="Edit">' . $website->name . '</a></td>' . "\n";
        echo '</tr>' . "\n";

        if ( $numOfArticles ) {
            $widget = new OnpubWidgetArticles( $this->pdo, $this->osection );
            $widget->display();

            echo '<tr>' . "\n";
            echo '<td><a href="javascript:moveSelectedOptionUp( articleList );"><img src="' . ONPUBGUI_IMAGE_DIRECTORY . 'up.png" border="0" alt="" /></a><img src="' . ONPUBGUI_IMAGE_DIRECTORY . 'buttonspacer.png" border="0" alt="" /><a href="javascript:moveSelectedOptionDown( articleList );"><img src="' . ONPUBGUI_IMAGE_DIRECTORY . 'down.png" border="0" alt="" /></a><img src="' . ONPUBGUI_IMAGE_DIRECTORY . 'buttonspacer.png" border="0" alt="" /><a href="javascript:removeSelectedArticle( articleList );"><img src="' . ONPUBGUI_IMAGE_DIRECTORY . 'remove.png" border="0" alt="" /></a></td>' . "\n";
            echo '</tr>' . "\n";
        }
        else {
            echo '<tr>' . "\n";
            echo '<td><b>Articles</b><br />' . "\n";
            echo 'There are 0 articles in the database.' . "\n";
            echo '</td>' . "\n";
            echo '</tr>' . "\n";
        }

        echo '</table>' . "\n";

        echo '<div><input type="hidden" name="onpub" value="EditSectionProcess" /></div>';
        echo '<div><input type="hidden" name="sectionID" value="' . $this->osection->ID . '" /></div>';

        echo '</form>' . "\n";

        echo '<script type="text/javascript">' . "\n";
        echo '<!--' . "\n";

        if ( $numOfArticles ) {
            echo '// convenience variables for form[0]\'s objects' . "\n";
            if ( sizeof ( $images ) ) {
                echo 'var articleList = document.forms[0].elements[3];' . "\n";
            }
            else {
                echo 'var articleList = document.forms[0].elements[2];' . "\n";
            }
        }

        echo '//-->' . "\n";
        echo '</script>' . "\n";

        $widget = new OnpubWidgetFooter();
        $widget->display();
    }

    public function validate()
    {
        if ( !$this->osection->name ) {
            $this->osection->name = null;
            return false;
        }

        return true;
    }

    public function process()
    {
        $osections = new OnpubSections( $this->pdo );

        try {
            $osections->update( $this->osection );
        }
        catch ( PDOException $e ) {
            throw $e;
        }
    }

    public function delete()
    {
        $osections = new OnpubSections( $this->pdo );

        try {
            $osections->delete( $this->osection->ID );
        }
        catch ( PDOException $e ) {
            throw $e;
        }
    }
}

?>