<?php

/**
 * @author {@link mailto:corey@onpubco.com Corey HM Taylor}
 * @copyright Onpub (TM) Copyright (C) 2007, Onpubco
 * {@link http://onpubco.com/}
 * @license http://www.gnu.org/copyleft/gpl.html GNU General Public License
 * Version 2
 * @package onpubgui
 * @version 0.8.6
 */
class OnpubEditSections
{
    private $pdo;
    private $orderBy;
    private $order;
    private $page;
    private $keywords;
    private $fullTextSearch;
    private $websiteID;

    function __construct( PDO $pdo, $orderBy = null, $order = null, $page = null, $keywords = null, $fullTextSearch = null, $websiteID = null )
    {
        $this->pdo = $pdo;
        $this->orderBy = $orderBy;
        $this->order = $order;
        $this->page = $page;
        $this->keywords = $keywords;
        $this->fullTextSearch = $fullTextSearch;
        $this->websiteID = $websiteID;
    }

    public function display()
    {
        $osections = new OnpubSections( $this->pdo );
        $owebsites = new OnpubWebsites( $this->pdo );
        $this->fullTextSearch = "NA";
        $counter = 0;
        $currentPage = 1;

        if ( $this->page ) {
            $currentPage = $this->page;
        }

        if ( $this->orderBy && $this->order ) {
            if ( $this->keywords ) {
                try {
                    $queryOptions = new OnpubQueryOptions();
                    $queryOptions->orderBy = $this->orderBy;
                    $queryOptions->order = $this->order;

                    $sections = $osections->search( $this->keywords, $queryOptions );
                }
                catch ( PDOException $e ) {
                    $widget = new OnpubWidgetPDOException( $e );
                    $widget->display();
                    return;
                }

                $totalSections = sizeof( $sections );
            }
            else {
                if ( $this->websiteID ) {
                    try {
                        $queryOptions = new OnpubQueryOptions();
                        $queryOptions->orderBy = $this->orderBy;
                        $queryOptions->order = $this->order;
                        $sections = $osections->select( $queryOptions, $this->websiteID );
                    }
                    catch ( PDOException $e ) {
                        $widget = new OnpubWidgetPDOException( $e );
                        $widget->display();
                        return;
                    }

                    $totalSections = sizeof( $sections );
                }
                else {
                    try {
                        $queryOptions = new OnpubQueryOptions();
                        $queryOptions->orderBy = $this->orderBy;
                        $queryOptions->order = $this->order;
                        $queryOptions->setPage( $currentPage, ONPUBGUI_PDO_ROW_LIMIT );
                        $sections = $osections->select( $queryOptions );
                    }
                    catch ( PDOException $e ) {
                        $widget = new OnpubWidgetPDOException( $e );
                        $widget->display();
                        return;
                    }

                    try {
                        $totalSections = $osections->count();
                    }
                    catch ( PDOException $e ) {
                        $widget = new OnpubWidgetPDOException( $e );
                        $widget->display();
                        return;
                    }
                }
            }
        }
        else {
            if ( $this->keywords ) {
                try {
                    $queryOptions = new OnpubQueryOptions();
                    $queryOptions->orderBy = "created";
                    $queryOptions->order = "DESC";

                    $sections = $osections->search( $this->keywords, $queryOptions );
                }
                catch ( PDOException $e ) {
                    $widget = new OnpubWidgetPDOException( $e );
                    $widget->display();
                    return;
                }

                $totalSections = sizeof( $sections );
            }
            else {
                if ( $this->websiteID ) {
                    try {
                        $queryOptions = new OnpubQueryOptions();
                        $queryOptions->orderBy = "created";
                        $queryOptions->order = "DESC";
                        $sections = $osections->select( $queryOptions, $this->websiteID );
                    }
                    catch ( PDOException $e ) {
                        $widget = new OnpubWidgetPDOException( $e );
                        $widget->display();
                        return;
                    }

                    $totalSections = sizeof( $sections );
                }
                else {
                    try {
                        $queryOptions = new OnpubQueryOptions();
                        $queryOptions->orderBy = "created";
                        $queryOptions->order = "DESC";
                        $queryOptions->setPage( $currentPage, ONPUBGUI_PDO_ROW_LIMIT );
                        $sections = $osections->select( $queryOptions );
                    }
                    catch ( PDOException $e ) {
                        $widget = new OnpubWidgetPDOException( $e );
                        $widget->display();
                        return;
                    }

                    try {
                        $totalSections = $osections->count();
                    }
                    catch ( PDOException $e ) {
                        $widget = new OnpubWidgetPDOException( $e );
                        $widget->display();
                        return;
                    }
                }
            }
        }

        $widget = new OnpubWidgetHeader( "Edit Sections" );
        $widget->display();

        echo '<form action="index.php" method="get">' . "\n";
        echo '<div><input type="hidden" name="onpub" value="EditSections" /></div>' . "\n";

        echo '<table border="0" cellpadding="3" cellspacing="2">' . "\n";

        if ( $totalSections ) {
            if ( !$this->keywords ) {
                $widget = new OnpubWidgetSelectWebsite( $this->pdo, $this->websiteID );
                $widget->display();
            }

            echo '<tr>' . "\n";
            $widget = new OnpubWidgetSearch( $totalSections, $this->keywords, $this->fullTextSearch );
            $widget->display();
            echo '</tr>' . "\n";

            echo '<tr>' . "\n";
            $widget = new OnpubWidgetPaginator( $totalSections, $this->orderBy, $this->order, $this->page, $this->keywords, $this->fullTextSearch, "websiteID", $this->websiteID, "EditSections" );
            $widget->display();
            echo '</tr>' . "\n";

            echo '<tr>' . "\n";
            echo '<td></td>' . "\n";

            if ( $this->keywords ) {
                $this->keywords = urlencode( $this->keywords );

                if ( $this->fullTextSearch ) {
                    switch ( $this->orderBy ) {
                        case "ID":
                        switch ( $this->order ) {
                            case "ASC":
                            echo '<td align="left" class="highlight2"><b><a href="index.php?onpub=EditSections&amp;keywords=' . $this->keywords . '&amp;fullTextSearch=' . $this->fullTextSearch . '&amp;orderBy=ID&amp;order=DESC">ID</a></b></td>' . "\n";
                            echo '<td align="left"><b><a href="index.php?onpub=EditSections&amp;keywords=' . $this->keywords . '&amp;fullTextSearch=' . $this->fullTextSearch . '&amp;orderBy=name&amp;order=ASC">Name</a></b></td>' . "\n";
                            echo '<td align="left"><b>Website</b></td>' . "\n";
                            echo '<td align="left"><b><a href="index.php?onpub=EditSections&amp;keywords=' . $this->keywords . '&amp;fullTextSearch=' . $this->fullTextSearch . '&amp;orderBy=created&amp;order=DESC">Created</a></b></td>' . "\n";
                            break;
                            case "DESC":
                            echo '<td align="left" class="highlight2"><b><a href="index.php?onpub=EditSections&amp;keywords=' . $this->keywords . '&amp;fullTextSearch=' . $this->fullTextSearch . '&amp;orderBy=ID&amp;order=ASC">ID</a></b></td>' . "\n";
                            echo '<td align="left"><b><a href="index.php?onpub=EditSections&amp;keywords=' . $this->keywords . '&amp;fullTextSearch=' . $this->fullTextSearch . '&amp;orderBy=name&amp;order=ASC">Name</a></b></td>' . "\n";
                            echo '<td align="left"><b>Website</b></td>' . "\n";
                            echo '<td align="left"><b><a href="index.php?onpub=EditSections&amp;keywords=' . $this->keywords . '&amp;fullTextSearch=' . $this->fullTextSearch . '&amp;orderBy=created&amp;order=DESC">Created</a></b></td>' . "\n";
                            break;
                        }
                        break;
                        case "name":
                        switch ( $this->order ) {
                            case "ASC":
                            echo '<td align="left"><b><a href="index.php?onpub=EditSections&amp;keywords=' . $this->keywords . '&amp;fullTextSearch=' . $this->fullTextSearch . '&amp;orderBy=ID&amp;order=DESC">ID</a></b></td>' . "\n";
                            echo '<td align="left" class="highlight2"><b><a href="index.php?onpub=EditSections&amp;keywords=' . $this->keywords . '&amp;fullTextSearch=' . $this->fullTextSearch . '&amp;orderBy=name&amp;order=DESC">Name</a></b></td>' . "\n";
                            echo '<td align="left"><b>Website</b></td>' . "\n";
                            echo '<td align="left"><b><a href="index.php?onpub=EditSections&amp;keywords=' . $this->keywords . '&amp;fullTextSearch=' . $this->fullTextSearch . '&amp;orderBy=created&amp;order=DESC">Created</a></b></td>' . "\n";
                            break;
                            case "DESC":
                            echo '<td align="left"><b><a href="index.php?onpub=EditSections&amp;keywords=' . $this->keywords . '&amp;fullTextSearch=' . $this->fullTextSearch . '&amp;orderBy=ID&amp;order=DESC">ID</a></b></td>' . "\n";
                            echo '<td align="left" class="highlight2"><b><a href="index.php?onpub=EditSections&amp;keywords=' . $this->keywords . '&amp;fullTextSearch=' . $this->fullTextSearch . '&amp;orderBy=name&amp;order=ASC">Name</a></b></td>' . "\n";
                            echo '<td align="left"><b>Website</b></td>' . "\n";
                            echo '<td align="left"><b><a href="index.php?onpub=EditSections&amp;keywords=' . $this->keywords . '&amp;fullTextSearch=' . $this->fullTextSearch . '&amp;orderBy=created&amp;order=DESC">Created</a></b></td>' . "\n";
                            break;
                        }
                        break;
                        default:
                        switch ( $this->order ) {
                            case "ASC":
                            echo '<td align="left"><b><a href="index.php?onpub=EditSections&amp;keywords=' . $this->keywords . '&amp;fullTextSearch=' . $this->fullTextSearch . '&amp;orderBy=ID&amp;order=DESC">ID</a></b></td>' . "\n";
                            echo '<td align="left"><b><a href="index.php?onpub=EditSections&amp;keywords=' . $this->keywords . '&amp;fullTextSearch=' . $this->fullTextSearch . '&amp;orderBy=name&amp;order=ASC">Name</a></b></td>' . "\n";
                            echo '<td align="left"><b>Website</b></td>' . "\n";
                            echo '<td align="left" class="highlight2"><b><a href="index.php?onpub=EditSections&amp;keywords=' . $this->keywords . '&amp;fullTextSearch=' . $this->fullTextSearch . '&amp;orderBy=created&amp;order=DESC">Created</a></b></td>' . "\n";
                            break;
                            case "DESC":
                            echo '<td align="left"><b><a href="index.php?onpub=EditSections&amp;keywords=' . $this->keywords . '&amp;fullTextSearch=' . $this->fullTextSearch . '&amp;orderBy=ID&amp;order=DESC">ID</a></b></td>' . "\n";
                            echo '<td align="left"><b><a href="index.php?onpub=EditSections&amp;keywords=' . $this->keywords . '&amp;fullTextSearch=' . $this->fullTextSearch . '&amp;orderBy=name&amp;order=ASC">Name</a></b></td>' . "\n";
                            echo '<td align="left"><b>Website</b></td>' . "\n";
                            echo '<td align="left" class="highlight2"><b><a href="index.php?onpub=EditSections&amp;keywords=' . $this->keywords . '&amp;fullTextSearch=' . $this->fullTextSearch . '&amp;orderBy=created&amp;order=ASC">Created</a></b></td>' . "\n";
                            break;
                            default:
                            echo '<td align="left"><b><a href="index.php?onpub=EditSections&amp;keywords=' . $this->keywords . '&amp;fullTextSearch=' . $this->fullTextSearch . '&amp;orderBy=ID&amp;order=DESC">ID</a></b></td>' . "\n";
                            echo '<td align="left"><b><a href="index.php?onpub=EditSections&amp;keywords=' . $this->keywords . '&amp;fullTextSearch=' . $this->fullTextSearch . '&amp;orderBy=name&amp;order=ASC">Name</a></b></td>' . "\n";
                            echo '<td align="left"><b>Website</b></td>' . "\n";
                            echo '<td align="left" class="highlight2"><b><a href="index.php?onpub=EditSections&amp;keywords=' . $this->keywords . '&amp;fullTextSearch=' . $this->fullTextSearch . '&amp;orderBy=created&amp;order=ASC">Created</a></b></td>' . "\n";
                            break;
                        }
                        break;
                    }
                }
                else {
                    switch ( $this->orderBy ) {
                        case "ID":
                        switch ( $this->order ) {
                            case "ASC":
                            echo '<td align="left" class="highlight2"><b><a href="index.php?onpub=EditSections&amp;keywords=' . $this->keywords . '&amp;orderBy=ID&amp;order=DESC">ID</a></b></td>' . "\n";
                            echo '<td align="left"><b><a href="index.php?onpub=EditSections&amp;keywords=' . $this->keywords . '&amp;orderBy=name&amp;order=ASC">Name</a></b></td>' . "\n";
                            echo '<td align="left"><b>Website</b></td>' . "\n";
                            echo '<td align="left"><b><a href="index.php?onpub=EditSections&amp;keywords=' . $this->keywords . '&amp;orderBy=created&amp;order=DESC">Created</a></b></td>' . "\n";
                            break;
                            case "DESC":
                            echo '<td align="left" class="highlight2"><b><a href="index.php?onpub=EditSections&amp;keywords=' . $this->keywords . '&amp;orderBy=ID&amp;order=ASC">ID</a></b></td>' . "\n";
                            echo '<td align="left"><b><a href="index.php?onpub=EditSections&amp;keywords=' . $this->keywords . '&amp;orderBy=name&amp;order=ASC">Name</a></b></td>' . "\n";
                            echo '<td align="left"><b>Website</b></td>' . "\n";
                            echo '<td align="left"><b><a href="index.php?onpub=EditSections&amp;keywords=' . $this->keywords . '&amp;orderBy=created&amp;order=DESC">Created</a></b></td>' . "\n";
                            break;
                        }
                        break;
                        case "name":
                        switch ( $this->order ) {
                            case "ASC":
                            echo '<td align="left"><b><a href="index.php?onpub=EditSections&amp;keywords=' . $this->keywords . '&amp;orderBy=ID&amp;order=DESC">ID</a></b></td>' . "\n";
                            echo '<td align="left" class="highlight2"><b><a href="index.php?onpub=EditSections&amp;keywords=' . $this->keywords . '&amp;orderBy=name&amp;order=DESC">Name</a></b></td>' . "\n";
                            echo '<td align="left"><b>Website</b></td>' . "\n";
                            echo '<td align="left"><b><a href="index.php?onpub=EditSections&amp;keywords=' . $this->keywords . '&amp;orderBy=created&amp;order=DESC">Created</a></b></td>' . "\n";
                            break;
                            case "DESC":
                            echo '<td align="left"><b><a href="index.php?onpub=EditSections&amp;keywords=' . $this->keywords . '&amp;orderBy=ID&amp;order=DESC">ID</a></b></td>' . "\n";
                            echo '<td align="left" class="highlight2"><b><a href="index.php?onpub=EditSections&amp;keywords=' . $this->keywords . '&amp;orderBy=name&amp;order=ASC">Name</a></b></td>' . "\n";
                            echo '<td align="left"><b>Website</b></td>' . "\n";
                            echo '<td align="left"><b><a href="index.php?onpub=EditSections&amp;keywords=' . $this->keywords . '&amp;orderBy=created&amp;order=DESC">Created</a></b></td>' . "\n";
                            break;
                        }
                        break;
                        default:
                        switch ( $this->order ) {
                            case "ASC":
                            echo '<td align="left"><b><a href="index.php?onpub=EditSections&amp;keywords=' . $this->keywords . '&amp;orderBy=ID&amp;order=DESC">ID</a></b></td>' . "\n";
                            echo '<td align="left"><b><a href="index.php?onpub=EditSections&amp;keywords=' . $this->keywords . '&amp;orderBy=name&amp;order=ASC">Name</a></b></td>' . "\n";
                            echo '<td align="left"><b>Website</b></td>' . "\n";
                            echo '<td align="left" class="highlight2"><b><a href="index.php?onpub=EditSections&amp;keywords=' . $this->keywords . '&amp;orderBy=created&amp;order=DESC">Created</a></b></td>' . "\n";
                            break;
                            case "DESC":
                            echo '<td align="left"><b><a href="index.php?onpub=EditSections&amp;keywords=' . $this->keywords . '&amp;orderBy=ID&amp;order=DESC">ID</a></b></td>' . "\n";
                            echo '<td align="left"><b><a href="index.php?onpub=EditSections&amp;keywords=' . $this->keywords . '&amp;orderBy=name&amp;order=ASC">Name</a></b></td>' . "\n";
                            echo '<td align="left"><b>Website</b></td>' . "\n";
                            echo '<td align="left" class="highlight2"><b><a href="index.php?onpub=EditSections&amp;keywords=' . $this->keywords . '&amp;orderBy=created&amp;order=ASC">Created</a></b></td>' . "\n";
                            break;
                            default:
                            echo '<td align="left"><b><a href="index.php?onpub=EditSections&amp;keywords=' . $this->keywords . '&amp;orderBy=ID&amp;order=DESC">ID</a></b></td>' . "\n";
                            echo '<td align="left"><b><a href="index.php?onpub=EditSections&amp;keywords=' . $this->keywords . '&amp;orderBy=name&amp;order=ASC">Name</a></b></td>' . "\n";
                            echo '<td align="left"><b>Website</b></td>' . "\n";
                            echo '<td align="left" class="highlight2"><b><a href="index.php?onpub=EditSections&amp;keywords=' . $this->keywords . '&amp;orderBy=created&amp;order=ASC">Created</a></b></td>' . "\n";
                            break;
                        }
                        break;
                    }
                }

                $this->keywords = urldecode( $this->keywords );
            }
            else {
                if ( $this->websiteID ) {
                    switch ( $this->orderBy ) {
                        case "ID":
                        switch ( $this->order ) {
                            case "ASC":
                            echo '<td align="left" class="highlight2"><b><a href="index.php?onpub=EditSections&amp;orderBy=ID&amp;order=DESC&websiteID=' . $this->websiteID . '">ID</a></b></td>' . "\n";
                            echo '<td align="left"><b><a href="index.php?onpub=EditSections&amp;orderBy=name&amp;order=ASC&websiteID=' . $this->websiteID . '">Name</a></b></td>' . "\n";
                            echo '<td align="left"><b>Website</b></td>' . "\n";
                            echo '<td align="left"><b><a href="index.php?onpub=EditSections&amp;orderBy=created&amp;order=DESC&websiteID=' . $this->websiteID . '">Created</a></b></td>' . "\n";
                            break;
                            case "DESC":
                            echo '<td align="left" class="highlight2"><b><a href="index.php?onpub=EditSections&amp;orderBy=ID&amp;order=ASC&websiteID=' . $this->websiteID . '">ID</a></b></td>' . "\n";
                            echo '<td align="left"><b><a href="index.php?onpub=EditSections&amp;orderBy=name&amp;order=ASC&websiteID=' . $this->websiteID . '">Name</a></b></td>' . "\n";
                            echo '<td align="left"><b>Website</b></td>' . "\n";
                            echo '<td align="left"><b><a href="index.php?onpub=EditSections&amp;orderBy=created&amp;order=DESC&websiteID=' . $this->websiteID . '">Created</a></b></td>' . "\n";
                            break;
                        }
                        break;
                        case "name":
                        switch ( $this->order ) {
                            case "ASC":
                            echo '<td align="left"><b><a href="index.php?onpub=EditSections&amp;orderBy=ID&amp;order=DESC&websiteID=' . $this->websiteID . '">ID</a></b></td>' . "\n";
                            echo '<td align="left" class="highlight2"><b><a href="index.php?onpub=EditSections&amp;orderBy=name&amp;order=DESC&websiteID=' . $this->websiteID . '">Name</a></b></td>' . "\n";
                            echo '<td align="left"><b>Website</b></td>' . "\n";
                            echo '<td align="left"><b><a href="index.php?onpub=EditSections&amp;orderBy=created&amp;order=DESC&websiteID=' . $this->websiteID . '">Created</a></b></td>' . "\n";
                            break;
                            case "DESC":
                            echo '<td align="left"><b><a href="index.php?onpub=EditSections&amp;orderBy=ID&amp;order=DESC&websiteID=' . $this->websiteID . '">ID</a></b></td>' . "\n";
                            echo '<td align="left" class="highlight2"><b><a href="index.php?onpub=EditSections&amp;orderBy=name&amp;order=ASC&websiteID=' . $this->websiteID . '">Name</a></b></td>' . "\n";
                            echo '<td align="left"><b>Website</b></td>' . "\n";
                            echo '<td align="left"><b><a href="index.php?onpub=EditSections&amp;orderBy=created&amp;order=DESC&websiteID=' . $this->websiteID . '">Created</a></b></td>' . "\n";
                            break;
                        }
                        break;
                        default:
                        switch ( $this->order ) {
                            case "ASC":
                            echo '<td align="left"><b><a href="index.php?onpub=EditSections&amp;orderBy=ID&amp;order=DESC&websiteID=' . $this->websiteID . '">ID</a></b></td>' . "\n";
                            echo '<td align="left"><b><a href="index.php?onpub=EditSections&amp;orderBy=name&amp;order=ASC&websiteID=' . $this->websiteID . '">Name</a></b></td>' . "\n";
                            echo '<td align="left"><b>Website</b></td>' . "\n";
                            echo '<td align="left" class="highlight2"><b><a href="index.php?onpub=EditSections&amp;orderBy=created&amp;order=DESC&websiteID=' . $this->websiteID . '">Created</a></b></td>' . "\n";
                            break;
                            case "DESC":
                            echo '<td align="left"><b><a href="index.php?onpub=EditSections&amp;orderBy=ID&amp;order=DESC&websiteID=' . $this->websiteID . '">ID</a></b></td>' . "\n";
                            echo '<td align="left"><b><a href="index.php?onpub=EditSections&amp;orderBy=name&amp;order=ASC&websiteID=' . $this->websiteID . '">Name</a></b></td>' . "\n";
                            echo '<td align="left"><b>Website</b></td>' . "\n";
                            echo '<td align="left" class="highlight2"><b><a href="index.php?onpub=EditSections&amp;orderBy=created&amp;order=ASC&websiteID=' . $this->websiteID . '">Created</a></b></td>' . "\n";
                            break;
                            default:
                            echo '<td align="left"><b><a href="index.php?onpub=EditSections&amp;orderBy=ID&amp;order=DESC&websiteID=' . $this->websiteID . '">ID</a></b></td>' . "\n";
                            echo '<td align="left"><b><a href="index.php?onpub=EditSections&amp;orderBy=name&amp;order=ASC&websiteID=' . $this->websiteID . '">Name</a></b></td>' . "\n";
                            echo '<td align="left"><b>Website</b></td>' . "\n";
                            echo '<td align="left" class="highlight2"><b><a href="index.php?onpub=EditSections&amp;orderBy=created&amp;order=ASC&websiteID=' . $this->websiteID . '">Created</a></b></td>' . "\n";
                            break;
                        }
                        break;
                    }
                }
                else {
                    switch ( $this->orderBy ) {
                        case "ID":
                        switch ( $this->order ) {
                            case "ASC":
                            echo '<td align="left" class="highlight2"><b><a href="index.php?onpub=EditSections&amp;orderBy=ID&amp;order=DESC">ID</a></b></td>' . "\n";
                            echo '<td align="left"><b><a href="index.php?onpub=EditSections&amp;orderBy=name&amp;order=ASC">Name</a></b></td>' . "\n";
                            echo '<td align="left"><b>Website</b></td>' . "\n";
                            echo '<td align="left"><b><a href="index.php?onpub=EditSections&amp;orderBy=created&amp;order=DESC">Created</a></b></td>' . "\n";
                            break;
                            case "DESC":
                            echo '<td align="left" class="highlight2"><b><a href="index.php?onpub=EditSections&amp;orderBy=ID&amp;order=ASC">ID</a></b></td>' . "\n";
                            echo '<td align="left"><b><a href="index.php?onpub=EditSections&amp;orderBy=name&amp;order=ASC">Name</a></b></td>' . "\n";
                            echo '<td align="left"><b>Website</b></td>' . "\n";
                            echo '<td align="left"><b><a href="index.php?onpub=EditSections&amp;orderBy=created&amp;order=DESC">Created</a></b></td>' . "\n";
                            break;
                        }
                        break;
                        case "name":
                        switch ( $this->order ) {
                            case "ASC":
                            echo '<td align="left"><b><a href="index.php?onpub=EditSections&amp;orderBy=ID&amp;order=DESC">ID</a></b></td>' . "\n";
                            echo '<td align="left" class="highlight2"><b><a href="index.php?onpub=EditSections&amp;orderBy=name&amp;order=DESC">Name</a></b></td>' . "\n";
                            echo '<td align="left"><b>Website</b></td>' . "\n";
                            echo '<td align="left"><b><a href="index.php?onpub=EditSections&amp;orderBy=created&amp;order=DESC">Created</a></b></td>' . "\n";
                            break;
                            case "DESC":
                            echo '<td align="left"><b><a href="index.php?onpub=EditSections&amp;orderBy=ID&amp;order=DESC">ID</a></b></td>' . "\n";
                            echo '<td align="left" class="highlight2"><b><a href="index.php?onpub=EditSections&amp;orderBy=name&amp;order=ASC">Name</a></b></td>' . "\n";
                            echo '<td align="left"><b>Website</b></td>' . "\n";
                            echo '<td align="left"><b><a href="index.php?onpub=EditSections&amp;orderBy=created&amp;order=DESC">Created</a></b></td>' . "\n";
                            break;
                        }
                        break;
                        default:
                        switch ( $this->order ) {
                            case "ASC":
                            echo '<td align="left"><b><a href="index.php?onpub=EditSections&amp;orderBy=ID&amp;order=DESC">ID</a></b></td>' . "\n";
                            echo '<td align="left"><b><a href="index.php?onpub=EditSections&amp;orderBy=name&amp;order=ASC">Name</a></b></td>' . "\n";
                            echo '<td align="left"><b>Website</b></td>' . "\n";
                            echo '<td align="left" class="highlight2"><b><a href="index.php?onpub=EditSections&amp;orderBy=created&amp;order=DESC">Created</a></b></td>' . "\n";
                            break;
                            case "DESC":
                            echo '<td align="left"><b><a href="index.php?onpub=EditSections&amp;orderBy=ID&amp;order=DESC">ID</a></b></td>' . "\n";
                            echo '<td align="left"><b><a href="index.php?onpub=EditSections&amp;orderBy=name&amp;order=ASC">Name</a></b></td>' . "\n";
                            echo '<td align="left"><b>Website</b></td>' . "\n";
                            echo '<td align="left" class="highlight2"><b><a href="index.php?onpub=EditSections&amp;orderBy=created&amp;order=ASC">Created</a></b></td>' . "\n";
                            break;
                            default:
                            echo '<td align="left"><b><a href="index.php?onpub=EditSections&amp;orderBy=ID&amp;order=DESC">ID</a></b></td>' . "\n";
                            echo '<td align="left"><b><a href="index.php?onpub=EditSections&amp;orderBy=name&amp;order=ASC">Name</a></b></td>' . "\n";
                            echo '<td align="left"><b>Website</b></td>' . "\n";
                            echo '<td align="left" class="highlight2"><b><a href="index.php?onpub=EditSections&amp;orderBy=created&amp;order=ASC">Created</a></b></td>' . "\n";
                            break;
                        }
                        break;
                    }
                }
            }

            echo '</tr>' . "\n";

            if ( $this->keywords || $this->websiteID ) {
                $index = (($currentPage - 1) * ONPUBGUI_PDO_ROW_LIMIT);
            }
            else {
                $index = 0;
            }

            for ( $i = 0; $i < ONPUBGUI_PDO_ROW_LIMIT && $index < sizeof( $sections ); $i++ ) {
                $section = $sections[$index];
                $this->ID = $sections[$index]->ID;
                $name = $sections[$index]->name;
                $created = $sections[$index]->getCreated()->format( "M j, Y" );
                $website = $owebsites->get( $sections[$index]->websiteID );
                $websiteName = $website->name;

                if ( $section->parentID ) {
                    $names = array();
                    $names[] = $name;
                    $name = "";

                    while ( $section->parentID ) {
                        $section = $section->parent;
                        $names[] = $section->name;
                    }

                    $names = array_reverse( $names );

                    for ( $j = 0; $j < sizeof( $names ); $j++ ) {
                        if ( $j == 0 ) {
                            $name .= $names[$j];
                        }
                        else {
                            $name .= ' &ndash; ' . $names[$j];
                        }
                    }
                }

                echo '<tr valign="top">' . "\n";
                echo '<td align="right"><input type="checkbox" name="sectionIDs[]" value="' . $this->ID . '" /></td>' . "\n";

                switch ( $this->order ) {
                    case "ASC":
                    switch ( $counter ) {
                        case 0:
                        echo '<td class="highlight1" align="right">' . $this->ID . '</td>' . "\n";
                        echo '<td class="highlight1" align="left"><a href="index.php?onpub=EditSection&amp;ID=' . $this->ID . '" title="Edit">' . $name . '</a></td>' . "\n";
                        echo '<td class="highlight1" align="left">' . $websiteName . '</td>' . "\n";
                        echo '<td class="highlight1" align="left">' . $created . '</td>' . "\n";
                        break;
                        case 1:
                        echo '<td class="highlight2" align="right">' . $this->ID . '</td>' . "\n";
                        echo '<td class="highlight2" align="left"><a href="index.php?onpub=EditSection&amp;ID=' . $this->ID . '" title="Edit">' . $name . '</a></td>' . "\n";
                        echo '<td class="highlight2" align="left">' . $websiteName . '</td>' . "\n";
                        echo '<td class="highlight2" align="left">' . $created . '</td>' . "\n";
                        break;
                    }
                    break;
                    case "DESC":
                    switch ( $counter ) {
                        case 0:
                        echo '<td class="highlight1" align="right">' . $this->ID . '</td>' . "\n";
                        echo '<td class="highlight1" align="left"><a href="index.php?onpub=EditSection&amp;ID=' . $this->ID . '" title="Edit">' . $name . '</a></td>' . "\n";
                        echo '<td class="highlight1" align="left">' . $websiteName . '</td>' . "\n";
                        echo '<td class="highlight1" align="left">' . $created . '</td>' . "\n";
                        break;
                        case 1:
                        echo '<td class="highlight2" align="right">' . $this->ID . '</td>' . "\n";
                        echo '<td class="highlight2" align="left"><a href="index.php?onpub=EditSection&amp;ID=' . $this->ID . '" title="Edit">' . $name . '</a></td>' . "\n";
                        echo '<td class="highlight2" align="left">' . $websiteName . '</td>' . "\n";
                        echo '<td class="highlight2" align="left">' . $created . '</td>' . "\n";
                        break;
                    }
                    break;
                    default:
                    switch ( $counter ) {
                        case 0:
                        echo '<td class="highlight1" align="right">' . $this->ID . '</td>' . "\n";
                        echo '<td class="highlight1" align="left"><a href="index.php?onpub=EditSection&amp;ID=' . $this->ID . '" title="Edit">' . $name . '</a></td>' . "\n";
                        echo '<td class="highlight1" align="left">' . $websiteName . '</td>' . "\n";
                        echo '<td class="highlight1" align="left">' . $created . '</td>' . "\n";
                        break;
                        case 1:
                        echo '<td class="highlight2" align="right">' . $this->ID . '</td>' . "\n";
                        echo '<td class="highlight2" align="left"><a href="index.php?onpub=EditSection&amp;ID=' . $this->ID . '" title="Edit">' . $name . '</a></td>' . "\n";
                        echo '<td class="highlight2" align="left">' . $websiteName . '</td>' . "\n";
                        echo '<td class="highlight2" align="left">' . $created . '</td>' . "\n";
                        break;
                    }
                    break;
                }

                echo '<td><a href="index.php?onpub=EditSection&amp;ID=' . $this->ID . '" title="Edit"><img src="' . ONPUBGUI_IMAGE_DIRECTORY . 'edit.png" width="60" height="25" alt="Edit" title="Edit" border="0" /></a></td>' . "\n";
                echo '<td></td>' . "\n";
                echo '</tr>' . "\n";

                if ( $counter + 1 == 2 ) {
                    $counter = 0;
                }
                else {
                    $counter++;
                }

                $index++;
            }
        }
        else {
            if ( $this->keywords ) {
                echo '<tr>' . "\n";
                $widget = new OnpubWidgetSearch( $totalSections, $this->keywords, $this->fullTextSearch );
                $widget->display();
                echo '</tr>' . "\n";
                echo '<tr>' . "\n";
                echo '<td>Your search did not yield any results. <a href="javascript:clearSearchField(); submitForm();">Display all sections</a>.</td>' . "\n";
                echo '</tr>' . "\n";
            }
            else {
                if ( $this->websiteID ) {
                    $widget = new OnpubWidgetSelectWebsite( $this->pdo, $this->websiteID );
                    $widget->display();
                    echo '<tr>' . "\n";
                    $widget = new OnpubWidgetSearch( $totalSections, $this->keywords, $this->fullTextSearch );
                    $widget->display();
                    echo '</tr>' . "\n";
                    echo '<tr>' . "\n";
                    echo '<td>There are 0 sections in the selected website. <a href="index.php?onpub=EditSections&amp;websiteID=">Display all sections</a>.</td>' . "\n";
                    echo '</tr>' . "\n";
                }
                else {
                    echo '<tr>' . "\n";
                    echo '<td>There are 0 sections in the database.</td>' . "\n";
                    echo '</tr>' . "\n";
                }
            }
        }

        if ( $totalSections ) {
            echo '<tr>' . "\n";
            $widget = new OnpubWidgetStats( $totalSections, $this->keywords, $this->websiteID, "Section", "Website" );
            $widget->display();
            echo '</tr>' . "\n";
        }

        echo '</table>' . "\n";

        echo '</form>' . "\n";

        $widget = new OnpubWidgetFooter();
        $widget->display();
    }
}

?>
