<?php

/**
 * @author {@link mailto:corey@onpubco.com Corey HM Taylor}
 * @copyright Onpub (TM) Copyright (C) 2007, Onpubco
 * {@link http://onpubco.com/}
 * @license http://www.gnu.org/copyleft/gpl.html GNU General Public License
 * Version 2
 * @package onpubgui
 * @version 0.8.6
 */
class OnpubEditWebsite
{
    private $pdo;
    private $owebsite;
    private $sectionIDs;

    function __construct( PDO $pdo, $owebsite, $sectionIDs = null )
    {
        $this->pdo = $pdo;
        $this->owebsite = $owebsite;
        $this->sectionIDs = $sectionIDs;
    }

    public function display()
    {
        $osections = new OnpubSections( $this->pdo );
        $owebsites = new OnpubWebsites( $this->pdo );
        $oimages = new OnpubImages( $this->pdo );
        $owsmaps = new OnpubWSMaps( $this->pdo );
        $queryOptions = new OnpubQueryOptions();
        $queryOptions->includeSections = true;

        try {
            $totalSections = $osections->count();
            $date = new DateTime();
            $this->owebsite = $owebsites->get( $this->owebsite->ID, $queryOptions );
            $queryOptions = new OnpubQueryOptions();
            $queryOptions->orderBy = "name";
            $queryOptions->order = "ASC";
            $websites = $owebsites->select( $queryOptions );

            $queryOptions = new OnpubQueryOptions();
            $queryOptions->orderBy = "fileName";
            $queryOptions->order = "ASC";
            $images = $oimages->select( $queryOptions );
        }
        catch ( PDOException $e ) {
            throw $e;
        }

        $widget = new OnpubWidgetHeader( "Website - " . $this->owebsite->name );
        $widget->display();

        echo '<form action="index.php" method="post" enctype="multipart/form-data">' . "\n";

        echo '<table border="0" cellpadding="5" cellspacing="0">' . "\n";
        echo '<tr>' . "\n";

        if ( $totalSections ) {
            echo '<td class="buttons"><a href="javascript:selectAll( sectionList ); submitForm();"><img src="' . ONPUBGUI_IMAGE_DIRECTORY . 'save.png" border="0" alt="" /></a> <a href="javascript:deleteWebsite();"><img src="' . ONPUBGUI_IMAGE_DIRECTORY . 'delete.png" border="0" alt="" /></a></td>' . "\n";
        }
        else {
            echo '<td class="buttons"><a href="javascript:submitForm();"><img src="' . ONPUBGUI_IMAGE_DIRECTORY . 'save.png" border="0" alt="" /></a> <a href="javascript:deleteWebsite();"><img src="' . ONPUBGUI_IMAGE_DIRECTORY . 'delete.png" border="0" alt="" /></a></td>' . "\n";
        }

        echo '</tr>' . "\n";

        echo '<tr>' . "\n";
        echo '<td><b>ID</b><br />' . $this->owebsite->ID . '</td>' . "\n";
        echo '</tr>' . "\n";

        echo '<tr>' . "\n";
        echo '<td><b>Created</b><br />' . $this->owebsite->getCreated()->format( 'M j, Y g:i:s A' ) . '' . "\n";
        echo '</tr>' . "\n";

        echo '<tr>' . "\n";
        echo '<td><b>Modified</b><br />' . $this->owebsite->getModified()->format( 'M j, Y g:i:s A' ) . '' . "\n";
        echo '</tr>' . "\n";

        echo '<tr>' . "\n";
        echo '<td><b>Name</b><br /><input type="text" maxlength="255" size="75" name="name" value="' . htmlentities( $this->owebsite->name ) . '" /></td>' . "\n";
        echo '</tr>' . "\n";

        $message = "";

        if ( $this->owebsite->url ) {
            $go = ' <b><a href="' . $this->owebsite->url . '" target="_blank"><img src="gui/icons/world_go.png" border="0" align="top" alt="Go" title="Go" width="16" height="16" /></a></b>';
        }
        else {
            $go = '';
        }

        echo '<tr>' . "\n";
        echo '<td><b>URL</b>' . $message . '<br /><input type="text" maxlength="255" size="75" name="url" value="' . htmlentities( $this->owebsite->url ) . '" />' . $go . '</td>' . "\n";
        echo '</tr>' . "\n";

        $message = "";

        if ( file_exists( $this->owebsite->imagesDirectory ) ) {
            if ( !is_writable( $this->owebsite->imagesDirectory ) ) {
                $message = '<img src="gui/icons/drive_error.png" align="top" width="16" height="16" alt="Directory is not writable" title="Directory is not writable" />';
            }
        }
        else {
            if ( $this->owebsite->imagesDirectory ) {
                $message = '<img src="gui/icons/drive_error.png" align="top" width="16" height="16" alt="Directory does not exist on ' . $_SERVER['SERVER_NAME'] . '" title="Directory does not exist on ' . $_SERVER['SERVER_NAME'] . '" />';
            }
        }

        echo '<tr>' . "\n";
        echo '<td><b>Images Directory</b><br /><small>Images uploaded to this website will be saved to this directory on <i>' . $_SERVER['SERVER_NAME'] . '</i></small><br /><input type="text" maxlength="255" size="75" name="imagesDirectory" value="' . htmlentities( $this->owebsite->imagesDirectory ) . '" /> ' . $message . '</td>' . "\n";
        echo '</tr>' . "\n";

        $message = "";

        if ( $this->owebsite->imagesURL ) {
            $message = '<br /><small>Images uploaded to this website should be accessible from this URL</small>';
        }
        else {
            $message = '<br /><small>Should be a URL to the Images Directory, example: http://onpubco.com/images/</small>';
        }

        if ( $this->owebsite->imagesURL ) {
            $go = ' <b><a href="' . $this->owebsite->imagesURL . '" target="_blank"><img src="gui/icons/world_go.png" border="0" align="top" alt="Go" title="Go" width="16" height="16" /></a></b>';
        }
        else {
            $go = '';
        }

        echo '<tr>' . "\n";
        echo '<td><b>Images URL</b>' . $message . '<br /><input type="text" maxlength="255" size="75" name="imagesURL" value="' . htmlentities( $this->owebsite->imagesURL ) . '" />' . $go . '</td>' . "\n";
        echo '</tr>' . "\n";

        $widget = new OnpubWidgetImages( "Logo", $this->owebsite->imageID, $images, $this->owebsite );
        $widget->display();

        if ( $totalSections ) {
            $widget = new OnpubWidgetSections( null, $websites, $osections, array(), "All Sections", true, "existingSections" );
            $widget->display();

            echo '<tr>' . "\n";
            echo '<td><a href="javascript:addExistingSection( existingSections, sectionList );"><img src="' . ONPUBGUI_IMAGE_DIRECTORY . 'add.png" border="0" alt="" /></a></td>' . "\n";
            echo '</tr>' . "\n";

            $widget = new OnpubWidgetSections( $this->sectionIDs, $websites, $osections, array(), "Public Sections", true, "sectionIDs[]", $this->owebsite );
            $widget->display();

            echo '<tr>' . "\n";
            echo '<td><a href="javascript:moveSelectedOptionUp( sectionList );"><img src="' . ONPUBGUI_IMAGE_DIRECTORY . 'up.png" border="0" alt="" /></a><img src="' . ONPUBGUI_IMAGE_DIRECTORY . 'buttonspacer.png" border="0" alt="" /><a href="javascript:moveSelectedOptionDown( sectionList );"><img src="' . ONPUBGUI_IMAGE_DIRECTORY . 'down.png" border="0" alt="" /></a><img src="' . ONPUBGUI_IMAGE_DIRECTORY . 'buttonspacer.png" border="0" alt="" /><a href="javascript:removeSelectedSection( sectionList );"><img src="' . ONPUBGUI_IMAGE_DIRECTORY . 'remove.png" border="0" alt="" /></a></td>' . "\n";
            echo '</tr>' . "\n";
        }

        echo '</table>' . "\n";

        echo '<div><input type="hidden" name="onpub" value="EditWebsiteProcess" /></div>';
        echo '<div><input type="hidden" name="websiteID" value="' . $this->owebsite->ID . '" /></div>';

        echo '</form>' . "\n";

        echo '<script type="text/javascript">' . "\n";
        echo '<!--' . "\n";

        echo "\n" . '// convenience variables for form[0]\'s objects' . "\n";
        echo 'var existingSections = document.forms[0].existingSections;' . "\n";

        if ( sizeof( $images ) ) {
            echo 'var sectionList = document.forms[0].elements[6];' . "\n";
        }
        else {
            echo 'var sectionList = document.forms[0].elements[5];' . "\n";
        }

        echo '//-->' . "\n";
        echo '</script>' . "\n";

        $widget = new OnpubWidgetFooter();
        $widget->display();
    }

    public function validate()
    {
        if ( !$this->owebsite->name ) {
            $this->owebsite->name = null;
            return false;
        }

        return true;
    }

    public function process()
    {
        $owebsites = new OnpubWebsites( $this->pdo );

        $sections = array();

        for ( $i = 0; $i < sizeof( $this->sectionIDs ); $i++ ) {
            if ( $this->sectionIDs[$i] ) {
                $section = new OnpubSection();

                $section->ID = $this->sectionIDs[$i];
                $section->websiteID = $this->owebsite->ID;

                $sections[] = $section;
            }
        }

        $this->owebsite->sections = $sections;

        try {
            $owebsites->update( $this->owebsite );
        }
        catch ( PDOException $e ) {
            throw $e;
        }
    }

    public function delete()
    {
        $owebsites = new OnpubWebsites( $this->pdo );

        try {
            $owebsites->delete( $this->owebsite->ID );
        }
        catch ( PDOException $e ) {
            throw $e;
        }
    }
}

?>